tlslite.utils.codec.Parser

Package tlslite :: Package utils :: Module codec :: Class Parser |
[show private | hide private]
[frames | no frames]

## Class Parser

Method Summary
| `__init__(self, bytes)`
| `atLengthCheck(self)`
| `get(self, length)`
| `getFixBytes(self, lengthBytes)`
| `getFixList(self, length, lengthList)`
| `getVarBytes(self, lengthLength)`
| `getVarList(self, length, lengthLength)`
| `setLengthCheck(self, length)`
| `startLengthCheck(self, lengthLength)`
| `stopLengthCheck(self)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net